# PoreMS: Pore Generator for Molecular Simulations

## Documentation

Online documentation is available at [ajax23.github.io/porems](https://ajax23.github.io/porems/).

The docs include an example for generating [molecules](https://ajax23.github.io/porems/molecule.html) and [pores](https://ajax23.github.io/porems/pore.html), and an [API reference](https://ajax23.github.io/porems/api.html). Additionally a [worklow](https://ajax23.github.io/porems/workflow.html) is provided, describing the programs operating principle.


## Dependencies

PoreMS supports Python 3.5+.

Installation requires [multiprocessing](https://docs.python.org/3/library/multiprocessing.html) and optionally [pandas](https://pandas.pydata.org/).


## Installation

The latest stable release (and older versions) can be installed from PyPI:

    pip install porems

You may instead want to use the development version from Github:

    pip install git+https://github.com/ajax23/porems.git#egg=porems

Or download the repository and install in the top directory via:

    pip install .


## Testing

To test porems, run the test in the test directory.


## Development

PoreMS development takes place on Github: https://github.com/Ajax23/PoreMS

Please submit any reproducible bugs you encounter to the [issue tracker](https://github.com/Ajax23/PoreMS/issues).
